contourpy
---------

Top level ContourPy module containing all the classes and functions required to generate and
manipulate contours.

.. toctree::
   :maxdepth: 2

   enums
   contour_generator
   ContourGenerator
   other
